#' @keywords internal 
"_PACKAGE"

#' hybridModels: an R package for stochastic simulation of disease spreading in dynamic networks.
#'
#' The hybridModels package provides functions to simulate stochastic models
#' in dynamics networks, using two processes in different scales:
#' 1 Global scale to simulate the transmission from one node to another
#' 2 Local scale to simulate the transmission inside the node
#' 
#' @section Modeling transmission of diseases:
#' 'Framework to run n simulations in dynamic network and plot results'
#'
#' @name hybridModels
NULL